@@ -611,7 +611,7 @@ enum TrashValidity {
 fn folder_validity(path: impl AsRef<Path>) -> Result<TrashValidity, FsError> {
     /// Mask for the sticky bit
     /// Taken from: http://man7.org/linux/man-pages/man7/inode.7.html
-    const S_ISVTX: u32 = 0x1000;
+    const S_ISVTX: u32 = 0o1000;
 
     let path = path.as_ref();
     let metadata = path.symlink_metadata().map_err(|e| (path.to_owned(), e))?;
@@ -630,13 +630,13 @@ fn folder_validity(path: impl AsRef<Path>) -> Result<TrashValidity, FsError> {
 /// https://specifications.freedesktop.org/trash-spec/trashspec-1.0.html
 fn home_trash() -> Result<PathBuf, Error> {
     if let Some(data_home) = std::env::var_os("XDG_DATA_HOME") {
-        if data_home.len() > 0 {
+        if !data_home.is_empty() {
             let data_home_path = AsRef::<Path>::as_ref(data_home.as_os_str());
             return Ok(data_home_path.join("Trash"));
         }
     }
     if let Some(home) = std::env::var_os("HOME") {
-        if home.len() > 0 {
+        if !home.is_empty() {
             let home_path = AsRef::<Path>::as_ref(home.as_os_str());
             return Ok(home_path.join(".local/share/Trash"));
         }
@@ -646,13 +646,13 @@ fn home_trash() -> Result<PathBuf, Error> {
 
 fn home_topdir(mnt_points: &[MountPoint]) -> Result<PathBuf, Error> {
     if let Some(data_home) = std::env::var_os("XDG_DATA_HOME") {
-        if data_home.len() > 0 {
+        if !data_home.is_empty() {
             let data_home_path = AsRef::<Path>::as_ref(data_home.as_os_str());
             return Ok(get_first_topdir_containing_path(data_home_path, mnt_points).to_owned());
         }
     }
     if let Some(home) = std::env::var_os("HOME") {
-        if home.len() > 0 {
+        if !home.is_empty() {
             let home_path = AsRef::<Path>::as_ref(home.as_os_str());
             return Ok(get_first_topdir_containing_path(home_path, mnt_points).to_owned());
         }
@@ -718,7 +718,7 @@ fn get_mount_points() -> Result<Vec<MountPoint>, Error> {
             break;
         }
         let dir = unsafe { CStr::from_ptr((*mntent).mnt_dir).to_str().unwrap() };
-        if dir.bytes().len() == 0 {
+        if dir.is_empty() {
             continue;
         }
         let mount_point = unsafe {
@@ -896,7 +896,7 @@ mod tests {
         let names: Vec<OsString> = (0..files_per_batch).map(|i| format!("{}#{}", file_name_prefix, i).into()).collect();
         for _ in 0..batches {
             for path in &names {
-                File::create(path).unwrap();
+                File::create_new(path).unwrap();
             }
             // eprintln!("Deleting {:?}", names);
             let result = delete_all_using_system_program(&names);
@@ -946,7 +946,7 @@ mod tests {
         let symlink_names: Vec<OsString> = names.iter().map(|name| format!("{:?}-symlink", name).into()).collect();
 
         // Test file symbolic link and directory symbolic link
-        File::create(&names[0]).unwrap();
+        File::create_new(&names[0]).unwrap();
         std::fs::create_dir(&names[1]).unwrap();
 
         for (i, (name, symlink)) in names.iter().zip(&symlink_names).enumerate() {
